@@ -38,7 +38,7 @@ from whenever import (
 
 from utilities.concurrent import concurrent_map
 from utilities.dataclasses import dataclass_to_dict
-from utilities.functions import ensure_class, is_string_mapping
+from utilities.functions import ensure_class
 from utilities.gzip import read_binary
 from utilities.iterables import (
     OneEmptyError,
@@ -51,6 +51,7 @@ from utilities.json import write_formatted_json
 from utilities.logging import get_logging_level_number
 from utilities.math import MAX_INT64, MIN_INT64
 from utilities.types import Dataclass, LogLevel, MaybeIterable, PathLike, StrMapping
+from utilities.typing import is_string_mapping
 from utilities.tzlocal import LOCAL_TIME_ZONE
 from utilities.version import Version, parse_version
 from utilities.whenever import (
